/* SPDX-License-Identifier: GPL-2.0-or-later */

/*
 * Copyright (C) 2020 by Nuvoton Technology Corporation
 * Mulin Chao <mlchao@nuvoton.com>
 * Wealian Liao <WHLIAO@nuvoton.com>
 *
 * Copyright (C) 2023 Benjamin VERNOUX 31 Aug 2023 (based on npcx_flash.h)
 */
#ifndef OPENOCD_LOADERS_FLASH_CX32L003_H
#define OPENOCD_LOADERS_FLASH_CX32L003_H

#include "cx32l003_flash_config.h"

/* Flash loader parameters */
struct __attribute__((__packed__)) cx32l003_flash_params {
	uint32_t addr; /* Address in flash */
	uint32_t len;  /* Number of bytes */
	uint32_t cmd;  /* Command */
	uint32_t sync; /* Handshake signal */
};

/* Flash trigger signal */
enum cx32l003_flash_handshake {
	CX32L003_FLASH_LOADER_WAIT    = 0x0,       /* Idle */
	CX32L003_FLASH_LOADER_EXECUTE = 0xFFFFFFFF /* Execute Command */
};

/* Flash loader command */
enum cx32l003_flash_commands {
	CX32L003_FLASH_CMD_NO_ACTION = 0, /* No action, default value */
	CX32L003_FLASH_CMD_GET_FLASH_ID,  /* Get the internal flash ID */
	CX32L003_FLASH_CMD_ERASE_SECTORS, /* Erase unprotected sectors */
	CX32L003_FLASH_CMD_ERASE_ALL,     /* Erase all */
	CX32L003_FLASH_CMD_PROGRAM,       /* Program data */
};

/* Status */
enum cx32l003_flash_status {
	CX32L003_FLASH_STATUS_OK = 0,
	CX32L003_FLASH_STATUS_FAILED_UNKNOWN_COMMAND,
	CX32L003_FLASH_STATUS_FAILED,
	CX32L003_FLASH_STATUS_FAILED_TIMEOUT,
};

#endif /* OPENOCD_LOADERS_FLASH_CX32L003_H */
