/* SPDX-License-Identifier: GPL-2.0-or-later */

/* Copyright (C) 2023 Benjamin VERNOUX 31 Aug 2023 */

#include "cx32l003_flash_config.h"

/* Application memory map */
MEMORY {
	/* buffer + parameters */
    BUFFER (RWX)  : ORIGIN = CX32L003_FLASH_LOADER_PARAMS_ADDR,
                      LENGTH = CX32L003_FLASH_LOADER_PARAMS_SIZE + CX32L003_FLASH_LOADER_BUFFER_SIZE

    PROGRAM (RWX)  : ORIGIN = CX32L003_FLASH_LOADER_PROGRAM_ADDR,
                     LENGTH = CX32L003_FLASH_LOADER_PROGRAM_SIZE
}

/* Sections used for flashing */
SECTIONS
{
	.buffers (NOLOAD) :
	{
		_buffers = .;
		*(.buffers.g_cfg)
		*(.buffers.g_buf)
		*(.buffers*)
		_ebuffers = .;
	} > BUFFER

	.text :
	{
		_text = .;
        KEEP(*(.entry*))
        KEEP(*(.text*))
		_etext = .;
	} > PROGRAM

	.data :
	{	_data = .;
		*(.rodata*)
		*(.data*)
		_edata = .;
	} > PROGRAM

	.bss :
	{
		__bss_start__ = .;
		_bss = .;
		*(.bss*)
		*(COMMON)
		_ebss = .;
		__bss_end__ = .;
	} > PROGRAM

	.stack (NOLOAD) :
	{
		_stack = .;
		. = . + CX32L003_FLASH_LOADER_STACK_SIZE;
		*(.stack*)
		_estack = .;
	} > PROGRAM
}
